@@ -1,5 +1,5 @@
 package MooX::Keyword;
-use 5.006; use strict; use warnings; our $VERSION = '1.00'; 
+use 5.006; use strict; use warnings; our $VERSION = '1.01'; 
 use MooX::ReturnModifiers; use Anonymous::Object;
 
 sub import {
@@ -48,7 +48,7 @@ MooX::Keyword - define custom keywords in Moo.
 
 =head1 VERSION
 
-Version 1.00
+Version 1.01
 
 =cut
 
@@ -146,23 +146,18 @@ You can also look for information at:
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=MooX-Keyword>
 
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/MooX-Keyword>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/MooX-Keyword>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2022 by LNATION.
+This software is Copyright (c) 2022->2025 by LNATION.
 
 This is free software, licensed under:
 
